/*
 * Sonar, open source software quality management tool.
 * Copyright (C) 2009 SonarSource SA
 * mailto:contact AT sonarsource DOT com
 *
 * Sonar is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sonar; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */

package org.sonar.plugins.cpd;

import org.apache.commons.configuration.Configuration;
import org.sonar.plugins.api.maven.Exclusions;
import org.sonar.plugins.api.maven.MavenCollector;
import org.sonar.plugins.api.maven.MavenPluginHandler;
import org.sonar.plugins.api.maven.ProjectContext;
import org.sonar.plugins.api.maven.model.MavenPom;

public class CpdMavenCollector implements MavenCollector {

  private CpdMapping[] cpdMappingList;
  private Configuration configuration;
  private Exclusions exclusions;

  public CpdMavenCollector(CpdMapping[] cpdMappingList, Configuration configuration, Exclusions exclusions) {
    this.cpdMappingList = cpdMappingList;
    this.configuration = configuration;
    this.exclusions = exclusions;
  }

  public Class<? extends MavenPluginHandler> dependsOnMavenPlugin(MavenPom pom) {
    return null;
  }

  public boolean shouldCollectOn(MavenPom pom) {
    return getCpdMapping(pom.getLanguageKey()) != null;
  }

  public void collect(MavenPom pom, ProjectContext context) {
    CpdExecutor executor = new CpdExecutor(pom, context, getCpdMapping(pom.getLanguageKey()), configuration, exclusions);
    executor.execute();
  }

  private CpdMapping getCpdMapping(String languageKey) {
    for (CpdMapping cpdMapping : cpdMappingList) {
      if (cpdMapping.getLanguage().getKey().equals(languageKey)) {
        return cpdMapping;
      }
    }
    return null;
  }

}
