/*
 * Sonar, open source software quality management tool.
 * Copyright (C) 2009 SonarSource SA
 * mailto:contact AT sonarsource DOT com
 *
 * Sonar is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sonar; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */

package org.sonar.plugins.cpd;

import org.sonar.plugins.api.EditableProperties;
import org.sonar.plugins.api.EditableProperty;
import org.sonar.plugins.api.Extension;
import org.sonar.plugins.api.Plugin;
import org.sonar.plugins.cpd.jobs.DuplicatedBlocksJob;
import org.sonar.plugins.cpd.jobs.DuplicatedFilesJob;
import org.sonar.plugins.cpd.jobs.DuplicatedLinesJob;
import org.sonar.plugins.cpd.jobs.DuplicatedLinesRatioJob;

import java.util.ArrayList;
import java.util.List;

@EditableProperties({
  @EditableProperty(key=CpdPlugin.CPD_MINIMUM_TOKENS_PROPERTY, defaultValue = CpdPlugin.CPD_MINIMUM_TOKENS_DEFAULT_VALUE,
    name = "CPD minimum token", description = "Minimum tokens count for copy paste detection")
})
public class CpdPlugin implements Plugin {

  public static final String KEY = "cpd";

  public final static String CPD_MINIMUM_TOKENS_PROPERTY = "sonar.cpd.minimumTokens";
  public final static String CPD_MINIMUM_TOKENS_DEFAULT_VALUE = "100";

  public String getKey() {
    return KEY;
  }

  public String getName() {
    return "CPD";
  }

  public String getDescription() {
    return "Finding copied and pasted code.";
  }

  public List<Class<? extends Extension>> getExtensions() {
    List<Class<? extends Extension>> list = new ArrayList<Class<? extends Extension>>();

    // maven collector
    list.add(CpdMavenCollector.class);

    // jobs
    list.add(DuplicatedBlocksJob.class);
    list.add(DuplicatedFilesJob.class);
    list.add(DuplicatedLinesJob.class);
    list.add(DuplicatedLinesRatioJob.class);

    // Java CPD Mapping
    list.add(JavaCpdMapping.class);

    return list;
  }
}